Installation
=============

You can install Django Menu Generator with one of these options:

- ``easy_install django-menu-generator``
- ``pip install django-menu-generator``
- ``git clone https://github.com/LaLogiaDePython/django-menu-generator``

  1. ``cd django-menu-generator``
  2. run python setup.py

- ``wget https://github.com/LaLogiaDePython/django-menu-generator/zipball/master``

  1. unzip the downloaded file
  2. cd into django-menu-generator-\* directory
  3. run python setup.py